@@ -13,7 +13,6 @@ import sys
 from PyQt5.QtWidgets import QApplication
 
 from tidal_gui import theme
-from tidal_gui.viewModel.loginModel import LoginModel
 from tidal_gui.viewModel.mainModel import MainModel
 
 
@@ -25,7 +24,10 @@ def main():
     mainView = MainModel()
     mainView.show()
 
-    sys.exit(app.exec_())
+    app.exec_()
+    mainView.uninit()
+
+    sys.exit()
 
 
 if __name__ == '__main__':
