@@ -8,15 +8,15 @@
 @Contact :  yaronhuang@foxmail.com
 @Desc    :
 """
-from PyQt5.QtWidgets import QComboBox, QListView
 from PyQt5.QtCore import Qt
+from PyQt5.QtWidgets import QComboBox, QListView
 
 
 class ComboBox(QComboBox):
-    def __init__(self, items: list):
+    def __init__(self, items: list, width: int = 200):
         super(ComboBox, self).__init__()
         self.setItems(items)
-        self.setFixedWidth(200)
+        self.setFixedWidth(width)
         self.setView(QListView())
         # remove shadow
         self.view().window().setWindowFlags(Qt.Popup | Qt.FramelessWindowHint | Qt.NoDropShadowWindowHint)
@@ -24,4 +24,4 @@ class ComboBox(QComboBox):
 
     def setItems(self, items):
         for item in items:
-            self.addItem(str(item))
\ No newline at end of file
+            self.addItem(str(item))
