@@ -8,9 +8,8 @@
 @Contact :  yaronhuang@foxmail.com
 @Desc    :
 """
-from PyQt5.QtCore import QSize
 from PyQt5.QtGui import QIcon
-from PyQt5.QtWidgets import QListWidget, QListWidgetItem
+from PyQt5.QtWidgets import QListWidget, QListWidgetItem, QWidget
 
 from tidal_gui.style import ListWidgetStyle
 
@@ -23,3 +22,11 @@ class ListWidget(QListWidget):
     def addIConTextItem(self, iconUrl: str, text: str):
         self.addItem(QListWidgetItem(QIcon(iconUrl), text))
 
+    def addWidgetItem(self, widget: QWidget):
+        item = QListWidgetItem(self)
+        # item.setSizeHint(QSize(widget.width(), widget.height()))
+        self.addItem(item)
+        self.setItemWidget(item, widget)
+
+    def setAdjustMode(self):
+        self.setResizeMode(QListWidget.Adjust)
