@@ -34,6 +34,12 @@ class ButtonStyle(Enum):
     PrePage = 14
     NextPage = 15
 
+    TaskRetry = 16,
+    TaskCancel = 17,
+    TaskDelete = 18,
+    TaskOpen = 19,
+    TaskExpand = 20,
+
 
 class LabelStyle(Enum):
     Default = 0,
@@ -41,6 +47,11 @@ class LabelStyle(Enum):
     PageSubTitle = 2,
     HugeTitle = 3,
     LogoBottom = 4,
+    SearchErr = 5,
+    Icon = 6,
+    Bold = 7,
+    Italic = 9,
+    Tag = 10
 
 
 class ThemeStyle(Enum):
@@ -51,4 +62,4 @@ class ThemeStyle(Enum):
 class ListWidgetStyle(Enum):
     Default = 0,
     TaskTab = 1,
-    TaskContent = 2,
+    DownloadItems = 2,
