@@ -9,10 +9,18 @@
 @Desc    :
 """
 
+import os
+
 import aigpy
 
 from tidal_gui.style import ThemeStyle
 
+_RESOURCE_PATH = './resource'
+if os.path.isdir(_RESOURCE_PATH):
+    _RESOURCE_PATH = os.path.abspath(_RESOURCE_PATH).replace('\\', '/')
+else:
+    _RESOURCE_PATH = aigpy.path.getDirName(__file__).replace('\\', '/') + "resource"
+
 
 def __getParam__(line: str):
     key = aigpy.string.getSub(line, "--", ":")
@@ -38,7 +46,7 @@ def __parseQss__(content: str, params: dict) -> str:
     for key in params:
         content = content.replace("var(--" + key + ")", params[key])
 
-    content = content.replace("$PACKAGE_PATH$", getPackagePath())
+    content = content.replace("$RESOURCE_PATH$", _RESOURCE_PATH)
     return content
 
 
@@ -49,12 +57,10 @@ def __getQss__(filePath: str) -> str:
     return qss
 
 
-def getPackagePath():
-    path = __file__
-    return aigpy.path.getDirName(path).replace('\\', '/')
+def getResourcePath():
+    return _RESOURCE_PATH
 
 
 def getThemeQssContent(style: ThemeStyle = ThemeStyle.Default):
     name = "theme" + style.name + ".qss"
-    path = getPackagePath() + "/resource/"
-    return __getQss__(path + name)
+    return __getQss__(_RESOURCE_PATH + '/' + name)
